#############
Reference/API
#############

=========
ROMSearch
=========

.. autoclass:: romsearch.ROMSearch
    :members:
    :undoc-members:

=============
ROMDownloader
=============

.. autoclass:: romsearch.ROMDownloader
    :members:
    :undoc-members:

=========
Utilities
=========

.. automodule:: romsearch.util
    :members:
    :undoc-members: